/**
 * \file eccderkeyparse.h
 *
 * \brief Public Key abstraction layer
 *
 *  Copyright (C) 2006-2015, ARM Limited, All Rights Reserved
 *  SPDX-License-Identifier: Apache-2.0
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may
 *  not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 *  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  This file is part of mbed TLS (https://tls.mbed.org)
 */

#ifndef MBEDTLS_ECCDERKEYPARSE_H
#define MBEDTLS_ECCDERKEYPARSE_H

#include "security_config.h"
#include "ecp.h"
#include "pk.h"


/**
 * \def MBEDTLS_ECCDERKEYPARSE_SELF_TEST
 *
 * Enable the checkup functions (*_self_test).
 */
#define MBEDTLS_ECCDERKEYPARSE_SELF_TEST


#ifdef __cplusplus
extern "C" {
#endif

int mbedtls_parse_ec_der_key(unsigned char *derkey, size_t keylen, mbedtls_ecp_keypair *eck);	
int mbedtls_parse_ec_der_pub_key(unsigned char *derkey, size_t keylen, mbedtls_ecp_keypair *eck);

#if defined(MBEDTLS_ECCDERKEYPARSE_SELF_TEST)		
int mbedtls_eccderkeyparse_self_test( int verbose );
	
#endif	//  MBEDTLS_ECCDERKEYPARSE_SELF_TEST
	
#ifdef __cplusplus
}
#endif

#endif /* MBEDTLS_ECCDERKEYPARSE_H */
